==> kea-docs-1%3A3.0.1-3-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d1/d22/ping__check__messages_8h.js <==
var ping__check__messages_8h =
[
    [ "PING_CHECK_CB4_UPDATE_FAILED", "d1/d22/ping__check__messages_8h.html#abf7f8d2dffa997526c29e19b38e69b58", null ],
    [ "PING_CHECK_CHANNEL_ECHO_REPLY_RECEIVED", "d1/d22/ping__check__messages_8h.html#a64783c28822adbab252efdec759cb2a6", null ],
    [ "PING_CHECK_CHANNEL_ECHO_REQUEST_SENT", "d1/d22/ping__check__messages_8h.html#aee016fbdd1717adaf4ddbddf89337340", null ],
    [ "PING_CHECK_CHANNEL_MALFORMED_PACKET_RECEIVED", "d1/d22/ping__check__messages_8h.html#a326a6041e943e68b915dd0ca84e99f90", null ],
    [ "PING_CHECK_CHANNEL_NETWORK_WRITE_ERROR", "d1/d22/ping__check__messages_8h.html#ad73945845db460be5f3ec33b57a7d33b", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_CLOSE_ERROR", "d1/d22/ping__check__messages_8h.html#ad4419c2f8c4d375f57906d48c3e34b06", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_CLOSED", "d1/d22/ping__check__messages_8h.html#a199592be4db5903e0e78740fbefee4d1", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_OPENED", "d1/d22/ping__check__messages_8h.html#aaabb178747a2fd573270d9e33fe1178d", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_READ_FAILED", "d1/d22/ping__check__messages_8h.html#a48bd29a32c7f8ebec4f3b65a80427ba0", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_WRITE_FAILED", "d1/d22/ping__check__messages_8h.html#a61e18065446ed10b4a2d97519b7ab15b", null ],
    [ "PING_CHECK_CHANNEL_STOP", "d1/d22/ping__check__messages_8h.html#a0323bbadfca8a5adf33b3d773826013b", null ],
    [ "PING_CHECK_CHANNEL_WATCH_SOCKET_CLEAR_ERROR", "d1/d22/ping__check__messages_8h.html#a11bb8cca4d9fc4c31c125434a1e11092", null ],
    [ "PING_CHECK_CHANNEL_WATCH_SOCKET_CLOSE_ERROR", "d1/d22/ping__check__messages_8h.html#acebe79f562c49ad75f7ed2062d02a522", null ],
    [ "PING_CHECK_DHCP4_SRV_CONFIGURED_FAILED", "d1/d22/ping__check__messages_8h.html#a84db6dd82739b2e00b79c4a438acb8de", null ],
    [ "PING_CHECK_DUPLICATE_CHECK", "d1/d22/ping__check__messages_8h.html#a3c37d232a8a643102b7975aa5167f3e4", null ],
    [ "PING_CHECK_LEASE4_OFFER_FAILED", "d1/d22/ping__check__messages_8h.html#a408c39c7a1dca0d008376dcc8447c0dd", null ],
    [ "PING_CHECK_LOAD_ERROR", "d1/d22/ping__check__messages_8h.html#a1f61e8c4e54d3b7bb865a1bfa5d7af9f", null ],
    [ "PING_CHECK_LOAD_OK", "d1/d22/ping__check__messages_8h.html#ad8c4c57c2617c0059f41729d42e6997f", null ],
    [ "PING_CHECK_MGR_CHANNEL_DOWN", "d1/d22/ping__check__messages_8h.html#a4677d87a2fba691b7782b856a3112cb4", null ],
    [ "PING_CHECK_MGR_LEASE_FREE_TO_USE", "d1/d22/ping__check__messages_8h.html#aa0e94d4859a3759910d425e94dac24e9", null ],
    [ "PING_CHECK_MGR_NEXT_ECHO_SCHEDULED", "d1/d22/ping__check__messages_8h.html#a274f0d8ccfdefb479f5023402cc86af7", null ],
    [ "PING_CHECK_MGR_RECEIVED_ECHO_REPLY", "d1/d22/ping__check__messages_8h.html#a6f079b527fbd18b6efba76c70f0fb0c9", null ],
    [ "PING_CHECK_MGR_RECEIVED_UNEXPECTED_ECHO_REPLY", "d1/d22/ping__check__messages_8h.html#a72cfbe78bcb1669066f008cd3a6be529", null ],
    [ "PING_CHECK_MGR_RECEIVED_UNEXPECTED_UNREACHABLE_MSG", "d1/d22/ping__check__messages_8h.html#ae1f3a288ff8fdeceb05d9a8c546b07d5", null ],
    [ "PING_CHECK_MGR_RECEIVED_UNREACHABLE_MSG", "d1/d22/ping__check__messages_8h.html#a544b2b0bfabe42cfb82716442573c49d", null ],
    [ "PING_CHECK_MGR_REPLY_RECEIVED_ERROR", "d1/d22/ping__check__messages_8h.html#a88124bb46c743295e0c5c0b6e8d42aa3", null ],
    [ "PING_CHECK_MGR_REPLY_TIMEOUT_EXPIRED", "d1/d22/ping__check__messages_8h.html#ad30956df9df709cd155ec2ecbe9a38e8", null ],
    [ "PING_CHECK_MGR_SEND_COMPLETED_ERROR", "d1/d22/ping__check__messages_8h.html#a8e8bba40d8e4eed5277e4fdfdc623cb3", null ],
    [ "PING_CHECK_MGR_START_PING_CHECK", "d1/d22/ping__check__messages_8h.html#adc67162306cf3a09f18ec124a47f19a7", null ],
    [ "PING_CHECK_MGR_STARTED", "d1/d22/ping__check__messages_8h.html#a0e72e78cfd5e1f2f4fb7ecfdf36717f6", null ],
    [ "PING_CHECK_MGR_STARTED_SINGLE_THREADED", "d1/d22/ping__check__messages_8h.html#a33908b26c6263648ac4f8a89533c5cfb", null ],
    [ "PING_CHECK_MGR_STOPPED", "d1/d22/ping__check__messages_8h.html#acc47a38c1fc640949120ccf9c10b0914", null ],
    [ "PING_CHECK_MGR_STOPPING", "d1/d22/ping__check__messages_8h.html#a7ea79ae4b9813d3992f8828fe4c0b6a4", null ],
    [ "PING_CHECK_MGR_SUBNET_CONFIG_FAILED", "d1/d22/ping__check__messages_8h.html#a91b68365cdea327b5d2d87159adff086", null ],
    [ "PING_CHECK_PAUSE_FAILED", "d1/d22/ping__check__messages_8h.html#ad3d04b0ee8807f8a9fe064638f28bdbb", null ],
    [ "PING_CHECK_PAUSE_ILLEGAL", "d1/d22/ping__check__messages_8h.html#af3474313d447c2368a15b545da34631c", null ],
    [ "PING_CHECK_PAUSE_PERMISSIONS_FAILED", "d1/d22/ping__check__messages_8h.html#aed65c5c51183fcf393c756d90dbd386f", null ],
    [ "PING_CHECK_RESUME_FAILED", "d1/d22/ping__check__messages_8h.html#a7d069df7bfe5c53fbb2a9a58ff4de850", null ],
    [ "PING_CHECK_UNEXPECTED_READ_ERROR", "d1/d22/ping__check__messages_8h.html#ab0254c05970dd5eebf13db58bbe434a6", null ],
    [ "PING_CHECK_UNEXPECTED_WRITE_ERROR", "d1/d22/ping__check__messages_8h.html#a9ef7e91b8b5e3a5da13a143dde3d9ca7", null ],
    [ "PING_CHECK_UNLOAD", "d1/d22/ping__check__messages_8h.html#ac8db4be575478245971cb4abf2d7dda7", null ]
];

==> kea-docs-1%3A3.0.2-1-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/d1/d22/ping__check__messages_8h.js <==
var ping__check__messages_8h =
[
    [ "PING_CHECK_CB4_UPDATE_FAILED", "d1/d22/ping__check__messages_8h.html#abf7f8d2dffa997526c29e19b38e69b58", null ],
    [ "PING_CHECK_CHANNEL_ECHO_REPLY_RECEIVED", "d1/d22/ping__check__messages_8h.html#a64783c28822adbab252efdec759cb2a6", null ],
    [ "PING_CHECK_CHANNEL_ECHO_REQUEST_SENT", "d1/d22/ping__check__messages_8h.html#aee016fbdd1717adaf4ddbddf89337340", null ],
    [ "PING_CHECK_CHANNEL_MALFORMED_PACKET_RECEIVED", "d1/d22/ping__check__messages_8h.html#a326a6041e943e68b915dd0ca84e99f90", null ],
    [ "PING_CHECK_CHANNEL_NETWORK_WRITE_ERROR", "d1/d22/ping__check__messages_8h.html#ad73945845db460be5f3ec33b57a7d33b", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_CLOSE_ERROR", "d1/d22/ping__check__messages_8h.html#ad4419c2f8c4d375f57906d48c3e34b06", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_CLOSED", "d1/d22/ping__check__messages_8h.html#a199592be4db5903e0e78740fbefee4d1", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_OPENED", "d1/d22/ping__check__messages_8h.html#aaabb178747a2fd573270d9e33fe1178d", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_READ_FAILED", "d1/d22/ping__check__messages_8h.html#a48bd29a32c7f8ebec4f3b65a80427ba0", null ],
    [ "PING_CHECK_CHANNEL_SOCKET_WRITE_FAILED", "d1/d22/ping__check__messages_8h.html#a61e18065446ed10b4a2d97519b7ab15b", null ],
    [ "PING_CHECK_CHANNEL_STOP", "d1/d22/ping__check__messages_8h.html#a0323bbadfca8a5adf33b3d773826013b", null ],
    [ "PING_CHECK_CHANNEL_WATCH_SOCKET_CLEAR_ERROR", "d1/d22/ping__check__messages_8h.html#a11bb8cca4d9fc4c31c125434a1e11092", null ],
    [ "PING_CHECK_CHANNEL_WATCH_SOCKET_CLOSE_ERROR", "d1/d22/ping__check__messages_8h.html#acebe79f562c49ad75f7ed2062d02a522", null ],
    [ "PING_CHECK_DHCP4_SRV_CONFIGURED_FAILED", "d1/d22/ping__check__messages_8h.html#a84db6dd82739b2e00b79c4a438acb8de", null ],
    [ "PING_CHECK_DUPLICATE_CHECK", "d1/d22/ping__check__messages_8h.html#a3c37d232a8a643102b7975aa5167f3e4", null ],
    [ "PING_CHECK_LEASE4_OFFER_FAILED", "d1/d22/ping__check__messages_8h.html#a408c39c7a1dca0d008376dcc8447c0dd", null ],
    [ "PING_CHECK_LOAD_ERROR", "d1/d22/ping__check__messages_8h.html#a1f61e8c4e54d3b7bb865a1bfa5d7af9f", null ],
    [ "PING_CHECK_LOAD_OK", "d1/d22/ping__check__messages_8h.html#ad8c4c57c2617c0059f41729d42e6997f", null ],
    [ "PING_CHECK_MGR_CHANNEL_DOWN", "d1/d22/ping__check__messages_8h.html#a4677d87a2fba691b7782b856a3112cb4", null ],
    [ "PING_CHECK_MGR_LEASE_FREE_TO_USE", "d1/d22/ping__check__messages_8h.html#aa0e94d4859a3759910d425e94dac24e9", null ],
    [ "PING_CHECK_MGR_NEXT_ECHO_SCHEDULED", "d1/d22/ping__check__messages_8h.html#a274f0d8ccfdefb479f5023402cc86af7", null ],
    [ "PING_CHECK_MGR_RECEIVED_ECHO_REPLY", "d1/d22/ping__check__messages_8h.html#a6f079b527fbd18b6efba76c70f0fb0c9", null ],
    [ "PING_CHECK_MGR_RECEIVED_UNEXPECTED_ECHO_REPLY", "d1/d22/ping__check__messages_8h.html#a72cfbe78bcb1669066f008cd3a6be529", null ],
    [ "PING_CHECK_MGR_RECEIVED_UNEXPECTED_UNREACHABLE_MSG", "d1/d22/ping__check__messages_8h.html#ae1f3a288ff8fdeceb05d9a8c546b07d5", null ],
    [ "PING_CHECK_MGR_RECEIVED_UNREACHABLE_MSG", "d1/d22/ping__check__messages_8h.html#a544b2b0bfabe42cfb82716442573c49d", null ],
    [ "PING_CHECK_MGR_REPLY_RECEIVED_ERROR", "d1/d22/ping__check__messages_8h.html#a88124bb46c743295e0c5c0b6e8d42aa3", null ],
    [ "PING_CHECK_MGR_REPLY_TIMEOUT_EXPIRED", "d1/d22/ping__check__messages_8h.html#ad30956df9df709cd155ec2ecbe9a38e8", null ],
    [ "PING_CHECK_MGR_SEND_COMPLETED_ERROR", "d1/d22/ping__check__messages_8h.html#a8e8bba40d8e4eed5277e4fdfdc623cb3", null ],
    [ "PING_CHECK_MGR_START_PING_CHECK", "d1/d22/ping__check__messages_8h.html#adc67162306cf3a09f18ec124a47f19a7", null ],
    [ "PING_CHECK_MGR_STARTED", "d1/d22/ping__check__messages_8h.html#a0e72e78cfd5e1f2f4fb7ecfdf36717f6", null ],
    [ "PING_CHECK_MGR_STARTED_SINGLE_THREADED", "d1/d22/ping__check__messages_8h.html#a33908b26c6263648ac4f8a89533c5cfb", null ],
    [ "PING_CHECK_MGR_STOPPED", "d1/d22/ping__check__messages_8h.html#acc47a38c1fc640949120ccf9c10b0914", null ],
    [ "PING_CHECK_MGR_STOPPING", "d1/d22/ping__check__messages_8h.html#a7ea79ae4b9813d3992f8828fe4c0b6a4", null ],
    [ "PING_CHECK_MGR_SUBNET_CONFIG_FAILED", "d1/d22/ping__check__messages_8h.html#a91b68365cdea327b5d2d87159adff086", null ],
    [ "PING_CHECK_NO_LEASE_OR_LEASE_REUSED", "d1/d22/ping__check__messages_8h.html#a6d36a0b73d51848f62738b7bacdd414b", null ],
    [ "PING_CHECK_PAUSE_FAILED", "d1/d22/ping__check__messages_8h.html#ad3d04b0ee8807f8a9fe064638f28bdbb", null ],
    [ "PING_CHECK_PAUSE_ILLEGAL", "d1/d22/ping__check__messages_8h.html#af3474313d447c2368a15b545da34631c", null ],
    [ "PING_CHECK_PAUSE_PERMISSIONS_FAILED", "d1/d22/ping__check__messages_8h.html#aed65c5c51183fcf393c756d90dbd386f", null ],
    [ "PING_CHECK_RESUME_FAILED", "d1/d22/ping__check__messages_8h.html#a7d069df7bfe5c53fbb2a9a58ff4de850", null ],
    [ "PING_CHECK_UNEXPECTED_READ_ERROR", "d1/d22/ping__check__messages_8h.html#ab0254c05970dd5eebf13db58bbe434a6", null ],
    [ "PING_CHECK_UNEXPECTED_WRITE_ERROR", "d1/d22/ping__check__messages_8h.html#a9ef7e91b8b5e3a5da13a143dde3d9ca7", null ],
    [ "PING_CHECK_UNLOAD", "d1/d22/ping__check__messages_8h.html#ac8db4be575478245971cb4abf2d7dda7", null ]
];
